@@ -1,7 +1,9 @@
+# -*- Perl -*-
+#
 # Implements ed(1) error handling. Run perldoc(1) on this module for
 # additional documentation.
 #
-# Copyright 2009 by Jeremy Mates.
+# Copyright 2009,2012 by Jeremy Mates.
 #
 # This module is free software; you can redistribute it and/or modify it
 # under the Artistic license.
@@ -10,7 +12,7 @@ package Acme::EdError;
 
 require 5.006;
 
-$VERSION = '0.01';
+$VERSION = '9.05';
 
 sub takeover_signals {
   $SIG{__DIE__} = sub { print STDERR "?\n"; exit 255 };
@@ -44,28 +46,30 @@ Acme::EdError - implements ed(1) error handling
 
 =head1 DESCRIPTION
 
-This module implements ed(1) error handling in perl, eliminating
-needless verbosity from error messages. To quote the ed(1) manual:
+This module implements L<ed(1)> error handling in perl, eliminating
+needless verbosity from warning and error messages. To quote the
+L<ed(1)> manual:
 
   "When an error occurs, ed prints a `?' and either returns to command
   mode or exits if its input is from a script. An explanation of the
   last error can be printed with the `h' (help) command."
 
-Help support has not yet been implemented in this module.
+Help support has not yet been implemented in this module. (And likely
+will not be.)
 
 =head1 SEE ALSO
 
-ed(1)
+L<ed(1)>
 
-http://github.com/thrig/Acme-EdError/tree/master
+L<http://github.com/thrig/Acme-EdError>
 
 =head1 AUTHOR
 
-Jeremy Mates, E<lt>jmates@sial.orgE<gt>
+Jeremy Mates, E<lt>jmates@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2009 by Jeremy Mates.
+Copyright 2009,2012 by Jeremy Mates.
 
 This module is free software; you can redistribute it and/or modify it
 under the Artistic license.
